@@ -129,9 +129,6 @@
 
 ;; grabbed from s7.scm:
 
-(define (string->keyword s)
-  (make-keyword s))
-
 (define (logtest a b)
   (not (zero? (logand a b))))
 
@@ -216,7 +213,7 @@
 
 (define (%alloc-pattern)
   ;; flags data length datum period value state limit returning counting traversing next mapr cache
-  (make-pattern 0 (list) #f +nad+ #f +nad+ +nad+ most-positive-fixnum #f #:periods #:depth-first
+  (make-pattern 0 (list) #f +nad+ #f +nad+ +nad+ (*s7* 'most-positive-fixnum) #f #:periods #:depth-first
 		#f #f #f))
 
 (define (initialize-pattern obj data for rep flags len dper getr mapr)
@@ -261,7 +258,7 @@
 			  +count-values+))
 	     (set! flags (logior flags +count-periods+)))))
   (pattern-repeat-set! obj (if (and (number? rep) (> rep 0))
-			       rep most-positive-fixnum))
+			       rep (*s7* 'most-positive-fixnum)))
   (let ((per (or for dper)))
     ;; period not specified so mark that we are using default period
     (when (not for)
@@ -1329,7 +1326,7 @@
 		(let ((obj (%alloc-pattern))
 		      (flags 0)
 		      )
-		  (initialize-pattern obj (list) for stop
+		  (initialize-pattern obj (list) for limit
 				      flags
 				      0
 				      1
@@ -1365,3 +1362,6 @@
 	  (pattern-data-set! obj (cdr data))
 	  (car data)))))
 
+
+;; (define aaa (make-repeater (make-weighting '(a b c d)) :for 2))
+;; (next aaa #t)
