@@ -10,12 +10,12 @@
 ;;; -------- strings (0-terminated)
 
 (define (io-read-string)
-  (let ((chars ()))
-    (do ((c (read-byte) (read-byte)))
-	((or (eof-object? c)
-	     (= c 0))
-	 (reverse (apply string chars)))
-      (set! chars (cons (integer->char c) chars)))))
+  (do ((chars ())
+       (c (read-byte) (read-byte)))
+      ((or (eof-object? c)
+	   (= c 0))
+       (reverse (apply string chars)))
+    (set! chars (cons (integer->char c) chars))))
 
 (define (io-write-string str)
   (format () "~{~A~}" str)
@@ -26,10 +26,13 @@
 ;;; -------- strings (unterminated)
 
 (define* (read-chars (len 4))
-  (let ((str (make-string len)))
-    (do ((i 0 (+ i 1)))
-	((= i len) str)
-      (set! (str i) (read-char)))))
+  (read-string len))
+#|
+  (do ((str (make-string len))
+       (i 0 (+ i 1)))
+      ((= i len) str)
+    (set! (str i) (read-char))))
+|#
 	 
 (define (write-chars str)
   (format () "~{~A~}" str))
@@ -88,16 +91,16 @@
 ;;; -------- 64-bit ints
 
 (define (read-bint64)
-  (let ((int 0))
-    (do ((i 56 (- i 8)))
-	((< i 0) int)
-      (set! int (logior int (ash (read-byte) i))))))
+  (do ((int 0)
+       (i 56 (- i 8)))
+      ((< i 0) int)
+    (set! int (logior int (ash (read-byte) i)))))
 
 (define (read-lint64)
-  (let ((int 0))
-    (do ((i 0 (+ i 8)))
-	((= i 64) int)
-      (set! int (logior int (ash (read-byte) i))))))
+  (do ((int 0)
+       (i 0 (+ i 8)))
+      ((= i 64) int)
+    (set! int (logior int (ash (read-byte) i)))))
     
 (define (write-bint64 int)
   (do ((i 56 (- i 8)))
@@ -185,26 +188,26 @@
 ;;; -------- 80-bit floats (IEEE 754, sign + 63(+1) bits significand + 15 bits exponent, needed for aifc headers)
 
 (define (read-bfloat80->int)
-  (let ((exp 0)
+  (let ((exponent 0)
 	(sign 0)
 	(buf (make-vector 10)))
     (do ((i 0 (+ i 1)))
 	((= i 10))
       (set! (buf i) (read-byte)))
-    (set! exp (logior (ash (buf 0) 8) (buf 1)))
-    (set! sign (if (not (= (logand exp #x8000) 0)) 1 0))
-    (set! exp (logand exp #x7FFF))
+    (set! exponent (logior (ash (buf 0) 8) (buf 1)))
+    (set! sign (if (not (= (logand exponent #x8000) 0)) 1 0))
+    (set! exponent (logand exponent #x7FFF))
     (let ((mant1 (+ (ash (buf 2) 24) (ash (buf 3) 16) (ash (buf 4) 8) (buf 5)))
 	  (mant0 (+ (ash (buf 6) 24) (ash (buf 7) 16) (ash (buf 8) 8) (buf 9))))
-      (if (= mant1 mant0 exp sign 0) 
+      (if (= mant1 mant0 exponent sign 0) 
 	  0
 	  (round (* (if (= sign 1) -1 1)
-		    (expt 2.0 (- exp 16383.0))
+		    (expt 2.0 (- exponent 16383.0))
 		    (+ (* (expt 2.0 -31.0) mant1)
 		       (* (expt 2.0 -63.0) mant0))))))))
 
 (define (write-int->bfloat80 val)
-  (let ((exp 0)    
+  (let ((exponent 0)    
 	(sign 0)
 	(mant1 0)
 	(mant0 0))
@@ -214,13 +217,13 @@
 	  (set! val (- val))))
     (if (not (zero? val))
 	(begin
-	  (set! exp (round (+ (log val 2.0) 16383.0)))
-	  (set! val (* val (expt 2 (- 16414 exp)))) ; 16414 = (+ 16383 31)
+	  (set! exponent (round (+ (log val 2.0) 16383.0)))
+	  (set! val (* val (expt 2 (- 16414 exponent)))) ; 16414 = (+ 16383 31)
 	  (set! mant1 (floor val))
 	  (set! val (- val mant1))
 	  (set! mant0 (floor (* val (expt 2 32))))))
-    (write-byte (logior (ash sign 7) (ash exp -8)))
-    (write-byte (logand exp #xFF))
+    (write-byte (logior (ash sign 7) (ash exponent -8)))
+    (write-byte (logand exponent #xFF))
     (do ((i 2 (+ i 1))
 	 (j 24 (- j 8)))
 	((= i 6))
@@ -239,7 +242,7 @@
     (lambda ()
       (let ((magic (read-chars)))
 	(if (not (string=? magic ".snd"))
-	    (error 'bad-header "~A is not an au file: ~A" file)
+	    (error 'bad-header "~A is not an au file" file)
 	    (let* ((data-location (read-bint32))
 		   (data-size (read-bint32))
 		   (sample-type (read-bint32))
@@ -276,12 +279,12 @@
       (lambda ()
 	(let ((magic (read-chars)))
 	  (if (not (string=? magic "FORM"))
-	      (error 'bad-header "~A is not an aif file: ~A" file magic)
-	      (let (;(size (read-bint32))
+	      (error 'bad-header "~A is not an aif file: ~S" file magic)
+	      (let ((size (read-bint32)) ; why was this commented out? the size is the 4 bytes after "FORM"
 		    (magic (read-chars)))
 		(set! current-location 12)
 		(if (not (member magic '("AIFF" "AIFC") string=?))
-		    (error 'bad-header "~A is not an aif file: ~A" file magic)
+		    (error 'bad-header "~A is not an aif file: ~S" file magic)
 		    ;; now look for the "SSND" and "COMM" chunks
 		    (call-with-exit
 		     (lambda (return)
