@@ -1,12 +1,10 @@
-# nb.rb -- translation of nb.rb
+# nb.rb -- translation of nb.scm
 
 # Translator/Author: Michael Scholz <mi-scholz@users.sourceforge.net>
-# Created: Tue Dec 10 22:08:15 CET 2002
-# Changed: Thu Oct 15 00:27:46 CEST 2009
+# Created: 2002/12/10 22:08:15
+# Changed: 2022/02/12 17:20:46
 
-# Commentary:
-#
-# Tested with Snd 9.5, Motif 2.2.2, Ruby 1.6.6, 1.6.8 and 1.8.6.
+# Tested with Snd 22.x, Ruby 3.x.x
 #
 # type nb = make_nb
 #      nb.help
@@ -45,14 +43,7 @@ nb.close                     # removes mouse hooks
 nb.help                      # this help
 =end
 
-# Code:
-
 require "hooks"
-with_silence do
-  unless defined? DBM.open
-    require "dbm"
-  end
-end
 
 $nb_database = "nb" unless defined? $nb_database
 
@@ -97,6 +88,7 @@ class NB
   
   def initialize(path)
     @nb_database = path
+    @nb = {}
     @type = nil
     @position = nil
     @name = nil
@@ -118,7 +110,7 @@ class NB
   end
   
   def name=(filename)
-    if filename and File.exists?(File.expand_path(filename))
+    if filename and File.exist?(File.expand_path(filename))
       @name = filename
       show_popup_info
     else
@@ -133,13 +125,7 @@ class NB
   end
 
   def with_dbm(&body)
-    ret = nil
-    db = DBM.open(@nb_database)
-    ret = body.call(db)
-    db.close
-    ret
-  rescue
-    Snd.warning("%s#%s", self.class, get_func_name)
+    body.call(@nb)
   end
 
   def prune_db
@@ -162,7 +148,7 @@ class NB
   end
   
   def unb
-    if @name and File.exists?(File.expand_path(@name))
+    if @name and File.exist?(File.expand_path(@name))
       with_dbm do |db|
         db.delete(@name)
       end
@@ -181,7 +167,7 @@ class NB
   end
 
   def nb
-    if @name and File.exists?(File.expand_path(@name))
+    if @name and File.exist?(File.expand_path(@name))
       with_dbm do |db|
         db[@name] = @notes
       end
@@ -203,7 +189,7 @@ class NB
       info_dialog(@name, file_info)
       if info_widget = dialog_widgets[Info_dialog]
         unless info_exists_p
-          width, height = widget_size(dialog_widgets[View_files_dialog])
+          width = widget_size(dialog_widgets[View_files_dialog])[0]
           set_widget_position(info_widget, [width + 10, 10])
         end
       end
@@ -218,9 +204,9 @@ class NB
     cs = mus_sound_chans(@name)
     sr = mus_sound_srate(@name)
     len = format("%1.3f", mus_sound_samples(@name).to_f / (cs * sr.to_f))
-    d_format = mus_data_format_name(mus_sound_data_format(@name))
+    d_format = mus_sample_type_name(mus_sound_sample_type(@name))
     h_type = mus_header_type_name(mus_sound_header_type(@name))
-    frms = mus_sound_frames(@name)
+    frms = mus_sound_framples(@name)
     max_amp = ""
     if mus_sound_maxamp_exists?(@name)
       str = ""
@@ -229,10 +215,11 @@ class NB
       end
       max_amp = format("\n maxamp: [%s]", str[0..-3])
     end
-    date = Time.at(mus_sound_write_date(@name)).localtime.strftime("%a %d-%b-%y %H:%M %Z")
+    fdate = Time.at(mus_sound_write_date(@name))
+    date = fdate.localtime.strftime("%a %d-%b-%y %H:%M %z")
     info_string = format("\
   chans: %d, srate: %d
- length: %1.3f (%d frames)
+ length: %1.3f (%d frms)
  format: %s [%s]%s
 written: %s\n", cs, sr, len, frms, d_format, h_type, max_amp, date)
     if defined?($info_comment_hook) and hook?($info_comment_hook)
@@ -241,7 +228,9 @@ written: %s\n", cs, sr, len, frms, d_format, h_type, max_amp, date)
           info_string += format("comment: %s\n", s)
         end
       else
-        $info_comment_hook.run_hook do |prc| info_string = prc.call(@name, info_string) end
+        $info_comment_hook.run_hook do |prc|
+          info_string = prc.call(@name, info_string)
+        end
       end
     else
       if s = mus_sound_comment(@name)
@@ -324,7 +313,9 @@ the $nb_database entries of SND will be returned.")
   attr_reader :popup_nb_hook
 
   def close
-    if @dialog.kind_of?(Dialog) and RWidget?(@dialog.dialog) and RXtIsManaged(@dialog.dialog)
+    if @dialog.kind_of?(Dialog) and
+       RWidget?(@dialog.dialog) and
+       RXtIsManaged(@dialog.dialog)
       RXtUnmanageChild(@dialog.dialog)
     end
     super
@@ -333,7 +324,7 @@ the $nb_database entries of SND will be returned.")
   protected
   def post_edit
     if !@name and RWidget?(@message_widget)
-      @name = if File.exists?(file = current_label(@message_widget).split[0])
+      @name = if File.exist?(file = current_label(@message_widget).split[0])
                 file
               else
                 format("no such file: %s", file.inspect)
@@ -348,8 +339,9 @@ the $nb_database entries of SND will be returned.")
                             end) do |w, c, i|
         self.notes = RXmTextGetString(@text_widget)
       end
-      @file_name = @dialog.add_label(@name, [RXmNbackground, help_button_color])
-      @text_widget = @dialog.add_text(:rows, 16, :columns, 60, :wordwrap, true, :value, @notes)
+      @file_name = @dialog.add_label(@name)
+      @text_widget = @dialog.add_text(:rows, 16, :columns, 60,
+                                      :wordwrap, true, :value, @notes)
       @dialog.doit_string("Submit")
     end
     activate_dialog(@dialog.dialog)
@@ -361,8 +353,8 @@ the $nb_database entries of SND will be returned.")
                   "Edit info DB of sound files (see nb.scm).
 
 Provides pop-up help in the Files viewer.  \
-If you have `dbm', any data associated with \
-the file in the dbm database will also be posted.  \
+Any data associated with the file \
+in the hash database will also be posted.  \
 The database name is defined by $nb_database \
 (#{$nb_database.inspect}).
 
@@ -383,12 +375,12 @@ o Submit:    submits info from edit widget
 #{self.description}",
                   ["{Libxm}: graphics module",
                    "{Ruby}: extension language",
-                   "{Motif}: Motif extensions via Libxm"])
-    end
+                   "{Motif}: Motif extensions via libxm"])
+  end
 
   def post_popup?
     $mouse_enter_label_hook.member?(@db_hook_name) and
-      File.exists?(current_label(@message_widget).split[0])
+      File.exist?(current_label(@message_widget).split[0])
   end
 
   private
@@ -412,14 +404,18 @@ o Submit:    submits info from edit widget
   
   def setup_menu(wid)
     @message_widget = find_child(wid, "Message")
-    make_snd_popup("NB Edit Info", :where, :event, :parent, find_child(wid, "post-it-text")) do
+    make_snd_popup("NB Edit Info",
+                   :where, :event,
+                   :parent, find_child(wid, "post-it-text")) do
       entry("Edit Info") do |w, snd, chn| Kernel.xm_nb.post_edit end
       entry("Prune DB") do |w, snd, chn| Kernel.xm_nb.prune_db end
       entry("Clear current Info") do |w, snd, chn| Kernel.xm_nb.unb end
       entry("Close NB Edit") do |w, snd, chn| Kernel.xm_nb.close end
       separator
       entry("Help") do |w, snd, chn| Kernel.xm_nb.help_cb end
-      before_popup_hook.add_hook!("NB Edit Info") do |d1, d2, d3| Kernel.xm_nb.post_popup? end
+      before_popup_hook.add_hook!("NB Edit Info") do |d1, d2, d3|
+        Kernel.xm_nb.post_popup?
+      end
     end
   end
 
@@ -430,8 +426,12 @@ o Submit:    submits info from edit widget
 
   def show_edit_info
     xfname = string2compound(@name)
-    RWidget?(@file_name) and RXtVaSetValues(@file_name, [RXmNlabelString, xfname])
-    RWidget?(@text_widget) and RXtVaSetValues(@text_widget, [RXmNvalue, @notes])
+    if RWidget?(@file_name)
+      RXtVaSetValues(@file_name, [RXmNlabelString, xfname])
+    end
+    if RWidget?(@text_widget)
+      RXtVaSetValues(@text_widget, [RXmNvalue, @notes])
+    end
     RXmStringFree(xfname)
   end
 end if provided?("xm")
