@@ -1,10 +1,10 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "11.4"
-#define S7_DATE "21-Apr-2025"
+#define S7_VERSION "11.5"
+#define S7_DATE "4-Aug-2025"
 #define S7_MAJOR_VERSION 11
-#define S7_MINOR_VERSION 4
+#define S7_MINOR_VERSION 5
 
 #include <stdint.h>           /* for int64_t */
 
@@ -30,17 +30,16 @@ typedef double s7_double;
   #include <mpc.h>
 #endif
 
-#if __TINYC__ || _MSC_VER || (__clang__ && __cplusplus)
+#if __TINYC__ || _MSC_VER
   /* _MSC_VER should also set HAVE_COMPLEX_NUMBERS to 0 */
   typedef double s7_complex;
 #else
-  #if __cplusplus /* only __GNUC__ */
+  #if __cplusplus
     #include <complex>
-    #ifdef __GNUC__
-      typedef std::complex<double> s7_complex;
+    #ifdef __clang__ /* defines __GNUC__ */
+      typedef _Complex double s7_complex;
     #else
-      using s7_complex = std::complex<double>;
-      /* sort of works in clang++ but there are many more problems */
+      typedef std::complex<double> s7_complex;
     #endif
   #else
     #include <complex.h>
@@ -389,17 +388,17 @@ s7_pointer s7_hook_set_functions(s7_scheme *sc, s7_pointer hook, s7_pointer func
 
 bool s7_is_input_port(s7_scheme *sc, s7_pointer p);                         /* (input-port? p) */
 bool s7_is_output_port(s7_scheme *sc, s7_pointer p);                        /* (output-port? p) */
-const char *s7_port_filename(s7_scheme *sc, s7_pointer x);                  /* (port-filename p) */
-s7_int s7_port_line_number(s7_scheme *sc, s7_pointer p);                    /* (port-line-number p) */
+const char *s7_port_filename(s7_scheme *sc, s7_pointer port);               /* (port-filename port) */
+s7_int s7_port_line_number(s7_scheme *sc, s7_pointer port);                 /* (port-line-number port) */
 
 s7_pointer s7_current_input_port(s7_scheme *sc);                            /* (current-input-port) */
-s7_pointer s7_set_current_input_port(s7_scheme *sc, s7_pointer p);          /* (set-current-input-port) */
+s7_pointer s7_set_current_input_port(s7_scheme *sc, s7_pointer port);       /* (set-current-input-port port) */
 s7_pointer s7_current_output_port(s7_scheme *sc);                           /* (current-output-port) */
-s7_pointer s7_set_current_output_port(s7_scheme *sc, s7_pointer p);         /* (set-current-output-port) */
+s7_pointer s7_set_current_output_port(s7_scheme *sc, s7_pointer port);      /* (set-current-output-port port) */
 s7_pointer s7_current_error_port(s7_scheme *sc);                            /* (current-error-port) */
-s7_pointer s7_set_current_error_port(s7_scheme *sc, s7_pointer port);       /* (set-current-error-port port) */
-void s7_close_input_port(s7_scheme *sc, s7_pointer p);                      /* (close-input-port p) */
-void s7_close_output_port(s7_scheme *sc, s7_pointer p);                     /* (close-output-port p) */
+s7_pointer s7_set_current_error_port(s7_scheme *sc, s7_pointer port);       /* (set-current-error-port port port) */
+void s7_close_input_port(s7_scheme *sc, s7_pointer port);                   /* (close-input-port port) */
+void s7_close_output_port(s7_scheme *sc, s7_pointer port);                  /* (close-output-port port) */
 s7_pointer s7_open_input_file(s7_scheme *sc, const char *name, const char *mode);
                                                                             /* (open-input-file name mode) */
 s7_pointer s7_open_output_file(s7_scheme *sc, const char *name, const char *mode);
@@ -410,8 +409,8 @@ s7_pointer s7_open_input_string(s7_scheme *sc, const char *input_string);
 s7_pointer s7_open_output_string(s7_scheme *sc);                            /* (open-output-string) */
 const char *s7_get_output_string(s7_scheme *sc, s7_pointer out_port);       /* (get-output-string port) -- current contents of output string */
   /*    don't free the string */
-s7_pointer s7_output_string(s7_scheme *sc, s7_pointer p);                   /*    same but returns an s7 string */
-bool s7_flush_output_port(s7_scheme *sc, s7_pointer p);                     /* (flush-output-port port) */
+s7_pointer s7_output_string(s7_scheme *sc, s7_pointer port);                /*    same but returns an s7 string */
+bool s7_flush_output_port(s7_scheme *sc, s7_pointer port);                  /* (flush-output-port port) */
 
 typedef enum {S7_READ, S7_READ_CHAR, S7_READ_LINE, S7_PEEK_CHAR, S7_IS_CHAR_READY, S7_NUM_READ_CHOICES} s7_read_t;
 s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, uint8_t c, s7_pointer port));
@@ -519,9 +518,16 @@ s7_pointer s7_define_constant_with_environment(s7_scheme *sc, s7_pointer envir,
 bool s7_is_function(s7_pointer p);
 bool s7_is_procedure(s7_pointer x);                                         /* (procedure? x) */
 bool s7_is_macro(s7_scheme *sc, s7_pointer x);                              /* (macro? x) */
-s7_pointer s7_closure_body(s7_scheme *sc, s7_pointer p);
-s7_pointer s7_closure_let(s7_scheme *sc, s7_pointer p);
-s7_pointer s7_closure_args(s7_scheme *sc, s7_pointer p);
+
+#if !S7_DISABLE_DEPRECATED
+  s7_pointer s7_closure_body(s7_scheme *sc, s7_pointer p);
+  s7_pointer s7_closure_let(s7_scheme *sc, s7_pointer p);
+  s7_pointer s7_closure_args(s7_scheme *sc, s7_pointer p);
+#endif
+s7_pointer s7_lambda_body(s7_scheme *sc, s7_pointer p);
+s7_pointer s7_lambda_let(s7_scheme *sc, s7_pointer p);
+s7_pointer s7_lambda_parameters(s7_scheme *sc, s7_pointer p);
+
 s7_pointer s7_funclet(s7_scheme *sc, s7_pointer p);                         /* (funclet x) */
 bool s7_is_aritable(s7_scheme *sc, s7_pointer x, s7_int args);              /* (aritable? x args) */
 s7_pointer s7_arity(s7_scheme *sc, s7_pointer x);                           /* (arity x) */
@@ -708,7 +714,7 @@ s7_pointer s7_c_object_set_let(s7_scheme *sc, s7_pointer obj, s7_pointer e);
 
 s7_int s7_make_c_type(s7_scheme *sc, const char *name);     /* create a new c_object type */
 
-/* old style free/mark/equal */
+/* old style free/mark/equal -- I'd like to deprecate these, but much old code depends on them */
 void s7_c_type_set_free         (s7_scheme *sc, s7_int tag, void (*gc_free)(void *value));
 void s7_c_type_set_mark         (s7_scheme *sc, s7_int tag, void (*mark)(void *value));
 void s7_c_type_set_equal        (s7_scheme *sc, s7_int tag, bool (*equal)(void *value1, void *value2));
@@ -948,6 +954,8 @@ bool s7_is_bignum(s7_pointer obj);
  *
  *        s7 changes
  *
+ * 7-June:    *s7* 'hash-table-missing-key-value and 'iterator-at-end-value.
+ *            replace s7_closure* with s7_lambda*.
  * 3-Apr:     c-object-let.
  * 10-Mar-24: s7_make_int_vector_wrapper.
  * --------
