@@ -327,17 +327,7 @@ static mus_float_t **make_black_and_white_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void black_and_white_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = 0.0;
-  (*g) = 0.0;
-  (*b) = 0.0;
-}
-#else
-  #define black_and_white_rgb NULL
-#endif
-
+#define black_and_white_rgb NULL
 
 /* colormap functions taken mostly from (GPL) octave-forge code written by Kai Habel <kai.habel@gmx.de> */
 
@@ -359,17 +349,7 @@ static mus_float_t **make_gray_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void gray_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = n;
-  (*g) = n;
-  (*b) = n;
-}
-#else
-  #define gray_rgb NULL
-#endif
-
+#define gray_rgb NULL
 
 static mus_float_t **make_autumn_colormap(int size, Xen ignored)
 {
@@ -389,16 +369,7 @@ static mus_float_t **make_autumn_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void autumn_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = 1.0;
-  (*g) = n;
-  (*b) = 0.0;
-}
-#else
-  #define autumn_rgb NULL
-#endif
+#define autumn_rgb NULL
 
 
 static mus_float_t **make_spring_colormap(int size, Xen ignored)
@@ -419,16 +390,7 @@ static mus_float_t **make_spring_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void spring_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = 1.0;
-  (*g) = n;
-  (*b) = 1.0 - n;
-}
-#else
-  #define spring_rgb NULL
-#endif
+#define spring_rgb NULL
 
 
 static mus_float_t **make_winter_colormap(int size, Xen ignored)
@@ -449,16 +411,7 @@ static mus_float_t **make_winter_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void winter_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = 0.0;
-  (*g) = n;
-  (*b) = 1.0 - (n * 0.5);
-}
-#else
-  #define winter_rgb NULL
-#endif
+#define winter_rgb NULL
 
 
 static mus_float_t **make_summer_colormap(int size, Xen ignored)
@@ -479,16 +432,7 @@ static mus_float_t **make_summer_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void summer_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = n;
-  (*g) = 0.5 + (0.5 * n);
-  (*b) = 0.4;
-}
-#else
-  #define summer_rgb NULL
-#endif
+#define summer_rgb NULL
 
 
 static mus_float_t **make_cool_colormap(int size, Xen ignored)
@@ -509,16 +453,7 @@ static mus_float_t **make_cool_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void cool_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = n;
-  (*g) = 1.0 - n;
-  (*b) = 1.0;
-}
-#else
-  #define cool_rgb NULL
-#endif
+#define cool_rgb NULL
 
 
 static mus_float_t **make_copper_colormap(int size, Xen ignored)
@@ -539,17 +474,7 @@ static mus_float_t **make_copper_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void copper_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < 0.8) ? (1.25 * x) : 1.0;
-  (*g) = 0.8 * x;
-  (*b) = 0.5 * x;
-}
-#else
-  #define copper_rgb NULL
-#endif
-
+#define copper_rgb NULL
 
 static mus_float_t **make_flag_colormap(int size, Xen ignored)
 {
@@ -569,18 +494,7 @@ static mus_float_t **make_flag_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void flag_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  int k;
-  k = ((int)(x * color_map_size(ss))) % 4;
-  (*r) = (k < 2) ? 1.0 : 0.0;
-  (*g) = (k == 1) ? 1.0 : 0.0;
-  (*b) = ((k == 1) || (k == 2)) ? 1.0 : 0.0;
-}
-#else
-  #define flag_rgb NULL
-#endif
+#define flag_rgb NULL
 
 
 static mus_float_t **make_prism_colormap(int size, Xen ignored)
@@ -604,22 +518,7 @@ static mus_float_t **make_prism_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void prism_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  int k;
-  mus_float_t rs[6] = {1.0, 1.0, 1.0, 0.0, 0.0, 0.6667};
-  mus_float_t gs[6] = {0.0, 0.5, 1.0, 1.0, 0.0, 0.0};
-  mus_float_t bs[6] = {0.0, 0.0, 0.0, 0.0, 1.0, 1.0};
-
-  k = ((int)(x * color_map_size(ss))) % 6;
-  (*r) = rs[k];
-  (*g) = gs[k];
-  (*b) = bs[k];
-}
-#else
-  #define prism_rgb NULL
-#endif
+#define prism_rgb NULL
 
 
 static mus_float_t **make_bone_colormap(int size, Xen ignored)
@@ -643,16 +542,7 @@ static mus_float_t **make_bone_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void bone_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < .75) ? (x * .875) : ((x * 11.0 / 8.0) - .375);
-  (*g) = (x < .375) ? (x * .875) : ((x < .75) ? ((x * 29.0 / 24.0) - .125) : ((x * .875) + .125));
-  (*b) = (x < .375) ? (x * 29.0 / 24.0) : ((x * .875) + .125);
-}
-#else
-  #define bone_rgb NULL
-#endif
+#define bone_rgb NULL
 
 
 static mus_float_t **make_hot_colormap(int size, Xen ignored)
@@ -677,16 +567,7 @@ static mus_float_t **make_hot_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void hot_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < .375) ? (x * 8.0 / 3.0) : 1.0;
-  (*g) = (x < .375) ? 0.0 : ((x < .75) ? ((x * 8.0 / 3.0) - 1.0) : 1.0);
-  (*b) = (x < .75) ? 0.0 : ((x * 4.0) - 3.0);
-}
-#else
-  #define hot_rgb NULL
-#endif
+#define hot_rgb NULL
 
 
 static mus_float_t **make_jet_colormap(int size, Xen ignored)
@@ -711,16 +592,7 @@ static mus_float_t **make_jet_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void jet_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < .375) ? 0.0 : ((x < .625) ? ((x * 4.0) - 1.5) : ((x < .875) ? 1.0 : ((x * -4.0) + 4.5)));
-  (*g) = (x < .125) ? 0.0 : ((x < .375) ? ((x * 4.0) - 0.5) : ((x < .625) ? 1.0 : ((x < .875) ? ((x * -4.0) + 3.5) : 0.0)));
-  (*b) = (x < .125) ? ((x * 4.0) + 0.5) : ((x < .375) ? 1.0 : ((x < .625) ? ((x * -4.0) + 2.5) : 0.0));
-}
-#else
-  #define jet_rgb NULL
-#endif
+#define jet_rgb NULL
 
 
 static mus_float_t **make_pink_colormap(int size, Xen ignored)
@@ -745,16 +617,7 @@ static mus_float_t **make_pink_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void pink_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < .375) ? (x * 14.0 / 9.0) : ((x * 2.0 / 3.0) + 1.0 / 3.0);
-  (*g) = (x < .375) ? (x * 2.0 / 3.0) : ((x < .75) ? ((x * 14.0 / 9.0) - 1.0 / 3.0) : ((x * 2.0 / 3.0) + 1.0 / 3.0));
-  (*b) = (x < .75) ? (x * 2.0 / 3.0) : ((x * 2.0) - 1.0);
-}
-#else
-  #define pink_rgb NULL
-#endif
+#define pink_rgb NULL
 
 
 static mus_float_t **make_rainbow_colormap(int size, Xen ignored)
@@ -779,16 +642,7 @@ static mus_float_t **make_rainbow_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-static void rainbow_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  (*r) = (x < .4) ? 1.0 : ((x < .6) ? ((x * -5.0) + 3.0) : ((x < .8) ? 0.0 : ((x * 10.0 / 3.0) - 8.0 / 3.0)));
-  (*g) = (x < .4) ? (x * 2.5) : ((x < .6) ? 1.0 : ((x < .8) ? ((x * -5.0) + 4.0) : 0.0));
-  (*b) = (x < .6) ? 0.0 : ((x < .8) ? ((x * 5.0) - 3.0) : 1.0);
-}
-#else
-  #define rainbow_rgb NULL
-#endif
+#define rainbow_rgb NULL
 
 
 static mus_float_t **make_phases_colormap(int size, Xen ignored)
@@ -836,45 +690,7 @@ static mus_float_t **make_phases_colormap(int size, Xen ignored)
 }
 
 
-#if USE_GTK
-void phases_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
-{
-  x *= (2.0 * M_PI); /* match code above */
-
-  if (x <= 0.5 * M_PI)
-    {
-      (*r) = x / (0.5 * M_PI);
-      (*g) = 0.0;
-      (*b) = 1.0 - (*r);
-    }
-  else
-    {
-      if (x <= M_PI)
-	{
-	  (*r) = 1.0 - ((x - 0.5 * M_PI) / (0.5 * M_PI));
-	  (*g) = 1.0 - (*r);
-	  (*b) = 0.0;
-	}
-      else
-	{
-	  if (x <= 1.5 * M_PI)
-	    {
-	      (*r) = 0.0;
-	      (*g) = 1.0 - ((x - M_PI) / (0.5 * M_PI));
-	      (*b) = 0.0;
-	    }
-	  else 
-	    {
-	      (*r) = 0.0;
-	      (*g) = 1.0 - ((x - (1.5 * M_PI)) / (0.5 * M_PI));
-	      (*b) = 0.0;
-	    }
-	}
-    }
-}
-#else
-  #define phases_rgb NULL
-#endif
+#define phases_rgb NULL
 
 
 /* ---------------------------------------- colormap objects ---------------------------------------- */
