@@ -163,6 +163,7 @@
 					  (set! (h (string->symbol name)) num)))))))))))))))))
     h))
 
+#|
 (define (combine . files)
   (let ((tables (map (lambda (file)
 		       (with-input-from-file file
@@ -247,6 +248,7 @@
 		     "v-imp"
 		     "v-lamb"
 		     "v-hook"
+		     "v-complex"
 		     "v-star")))
     (define (next-file f)
       (let ((name (system (format #f "ls -t ~A*" f) #t)))
@@ -260,7 +262,6 @@
     (apply combine (map next-file file-names))))
 
 
-#|
 ;;; show all timing test overheads
 
 (define (get-overheads file)
@@ -298,48 +299,59 @@
 	(list-tail overheads (max 10 (- (length overheads) 20)))))))
 
 
-(define file-names '(("make-index.scm" . "/home/bil/motif-snd/v-index85")
-		     ("tmac.scm" . "/home/bil/motif-snd/v-mac85")
-		     ("tpeak.scm" . "/home/bil/motif-snd/v-peak85")
-		     ("tvect.scm" . "/home/bil/motif-snd/v-vect85")
-		     ("teq.scm" . "/home/bil/motif-snd/v-eq85")
-		     ("tfft.scm" . "/home/bil/motif-snd/v-fft85")
-		     ("tref.scm" . "/home/bil/motif-snd/v-ref85")
-		     ("tauto.scm" . "/home/bil/motif-snd/v-auto85")
-		     ("s7test.scm" . "/home/bil/motif-snd/v-test85")
-		     ("tcopy.scm" . "/home/bil/motif-snd/v-cop85")
+(define file-names '(
+		     ("concordance.scm" . "/home/bil/motif-snd/v-str85")
+		     ("dup.scm" . "/home/bil/motif-snd/v-dup85")
+		     ("fbench.scm" . "/home/bil/motif-snd/v-fb85")
+		     ("full-snd-test.scm" . "/home/bil/motif-snd/v-sg85")
 		     ("lt.scm" . "/home/bil/motif-snd/v-lt85")
+		     ("s7test.scm" . "/home/bil/motif-snd/v-test85")
+		     ("snd-test.scm" . "/home/bil/motif-snd/v-call85")
+		     ("tall.scm" . "/home/bil/motif-snd/v-all85")
+		     ("tari.scm" . "/home/bil/motif-snd/v-ari85")
+		     ("tauto.scm" . "/home/bil/motif-snd/v-auto85")
+		     ("tbig.scm" . "/home/bil/motif-snd/v-big85")
+		     ("tcase.scm" . "/home/bil/motif-snd/v-case85")
+		     ("tclo.scm" . "/home/bil/motif-snd/v-clo85")
+		     ("tcomplex.scm" . "/home/bil/motif-snd/v-complex85")
+		     ("tcopy.scm" . "/home/bil/motif-snd/v-cop85")
+		     ("teq.scm" . "/home/bil/motif-snd/v-eq85")
+		     ("texit.scm" . "/home/bil/motif-snd/v-exit85")
+		     ("tfft.scm" . "/home/bil/motif-snd/v-fft85")
 		     ("tform.scm" . "/home/bil/motif-snd/v-form85")
-		     ("tread.scm" . "/home/bil/motif-snd/v-read85")
+		     ("tgc.scm" . "/home/bil/motif-snd/v-gc85")
+		     ("tgen.scm" . "/home/bil/motif-snd/v-gen85")
+                     ("tgsl.scm" . "/home/bil/motif-snd/v-gsl85")
+		     ("thash.scm" . "/home/bil/motif-snd/v-hash85")
+		     ("thook.scm" . "/home/bil/motif-snd/v-hook85")
+		     ("timp.scm" . "/home/bil/motif-snd/v-imp85")
+		     ("tio.scm" . "/home/bil/motif-snd/v-io85")
+		     ("titer.scm" . "/home/bil/motif-snd/v-iter85")
+		     ("tlamb.scm" . "/home/bil/motif-snd/v-lamb85")
+		     ("tleft.scm" . "/home/bil/motif-snd/v-left85")
+		     ("tlet.scm" . "/home/bil/motif-snd/v-let85")
+		     ("tlimit.scm" . "/home/bil/motif-snd/v-limit85")
+		     ("tlist.scm" . "/home/bil/motif-snd/v-list85")
+		     ("tload.scm" . "/home/bil/motif-snd/v-load85")
+		     ("tmac.scm" . "/home/bil/motif-snd/v-mac85")
+		     ("tmap-hash.scm" . "/home/bil/motif-snd/v-map-hash85")
 		     ("tmap.scm" . "/home/bil/motif-snd/v-map85")
 		     ("tmat.scm" . "/home/bil/motif-snd/v-mat85")
 		     ("tmisc.scm" . "/home/bil/motif-snd/v-misc85")
-		     ("titer.scm" . "/home/bil/motif-snd/v-iter85")
-		     ("tsort.scm" . "/home/bil/motif-snd/v-sort85")
-		     ("tlet.scm" . "/home/bil/motif-snd/v-let85")
-		     ("thash.scm" . "/home/bil/motif-snd/v-hash85")
-		     ("tmap-hash.scm" . "/home/bil/motif-snd/v-map-hash85")
-                     ("tmv.scm" . "/home/bil/motif-snd/v-mv85")
-		     ("tgen.scm" . "/home/bil/motif-snd/v-gen85")
-		     ("tall.scm" . "/home/bil/motif-snd/v-all85")
-		     ("snd-test.scm" . "/home/bil/motif-snd/v-call85")
-		     ("full-snd-test.scm" . "/home/bil/motif-snd/v-sg85")
-		     ("dup.scm" . "/home/bil/motif-snd/v-dup85")
-		     ("tset.scm" . "/home/bil/motif-snd/v-set85")
-		     ("trec.scm" . "/home/bil/motif-snd/v-rec85")
-		     ("tclo.scm" . "/home/bil/motif-snd/v-clo85")
-		     ("tbig.scm" . "/home/bil/motif-snd/v-big85")
-		     ("tshoot.scm" . "/home/bil/motif-snd/v-shoot85")
-		     ("fbench.scm" . "/home/bil/motif-snd/v-fb85")
-		     ("trclo.scm" . "/home/bil/motif-snd/v-rclo85")
-		     ("tcase.scm" . "/home/bil/motif-snd/v-case85")
-		     ;("test-all.scm" . "/home/bil/motif-snd/v-b85")
-		     ("tio.scm" . "/home/bil/motif-snd/v-io85")
-		     ("tgc.scm" . "/home/bil/motif-snd/v-gc85")
-		     ("tnum.scm" . "/home/bil/motif-snd/v-num85")
 		     ("tmock.scm" . "/home/bil/motif-snd/v-mock85")
-		     ("concordance.scm" . "/home/bil/motif-snd/v-str85")
-                     ("tgsl.scm" . "/home/bil/motif-snd/v-gsl85")
+		     ("tmv.scm" . "/home/bil/motif-snd/v-mv85")
+		     ("tnum.scm" . "/home/bil/motif-snd/v-num85")
+		     ("tpeak.scm" . "/home/bil/motif-snd/v-peak85")
+		     ("trclo.scm" . "/home/bil/motif-snd/v-rclo85")
+		     ("tread.scm" . "/home/bil/motif-snd/v-read85")
+		     ("trec.scm" . "/home/bil/motif-snd/v-rec85")
+		     ("tref.scm" . "/home/bil/motif-snd/v-ref85")
+		     ("tset.scm" . "/home/bil/motif-snd/v-set85")
+		     ("tshoot.scm" . "/home/bil/motif-snd/v-shoot85")
+		     ("tsort.scm" . "/home/bil/motif-snd/v-sort85")
+		     ("tstar.scm" . "/home/bil/motif-snd/v-sort85")
+		     ("tvect.scm" . "/home/bil/motif-snd/v-star85")
+                     ("make-index.scm" . "/home/bil/motif-snd/v-index85")
 		     ))
 
 (for-each (lambda (file)
