@@ -29,6 +29,8 @@
 	 (format p "(define aux-counter ~D)\n" aux-counter)
 	 (format p "(define-macro (test tst expected) ~A)~%" test-case)
 	 (format p "(define-macro (num-test tst expected) ~A)~%" (string-append "`(nok? " (substring test-case 5)))
+	 (when (= aux-counter 35)
+	   (format p "(set! (hook-functions *rootlet-redefinition-hook*) (list (lambda (hook) (format *stderr* \"redefine rootlet ~~A ~~A~~%\" (hook 'name) (hook 'value)))))"))
 	 (format p "(load \"s7test.scm\")~%(exit)~%")))
      (format *stderr* "~%~NC~%test: ~S~%" 80 #\- test-case)
      (system (string-append "./repl " aux-file))))
