@@ -12,64 +12,46 @@
 	 (<= a b)))
   (define (closure-less a b)
     (and (< a b)
-	 (= (abs (+ (* 2 (- 3)) 1)) 5))) ; force optimizer to give up! [but it is now smarter...]
+	 (= (abs (+ (* 2 (- 3)) 1)) 5))) ; force optimizer to give up!
   (define (begin-less a b)
     (if (and (< a b) (> a b)) (display "oops"))
     (< a b))
   
   (define (check-numbers vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (> x y)
-	     (format *stderr* "~A > ~A?~%" x y))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (> (vector-ref vc (- j 1)) (vector-ref vc j))
+	  (format *stderr* "~A > ~A?~%" (vector-ref vc (- j 1)) (vector-ref vc j)))))
 	 
   (define (check-chars vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (char>? x y)
-	     (format *stderr* "~A > ~A?~%" x y))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (char>? (vector-ref vc (- j 1)) (vector-ref vc j))
+	  (format *stderr* "~A > ~A?~%" (vector-ref vc (- j 1)) (vector-ref vc j)))))
     
   (define (check-strings vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (string>? x y)
-	     (format *stderr* "~A > ~A?~%" x y))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (string>? (vector-ref vc (- j 1)) (vector-ref vc j))
+	  (format *stderr* "~A > ~A?~%" (vector-ref vc (- j 1)) (vector-ref vc j)))))
 
   (define (check-car vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (> (car x) (car y)) 
-	     (format *stderr* "~A > ~A?~%" (car x) (car y)))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (> (car (vector-ref vc (- j 1))) (car (vector-ref vc j)))
+	  (format *stderr* "~A > ~A?~%" (car (vector-ref vc (- j 1))) (car (vector-ref vc j))))))
   
   (define (check-cdr vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (> (cdr x) (cdr y)) 
-	     (format *stderr* "~A > ~A?~%" (cdr x) (cdr y)))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (> (cdr (vector-ref vc (- j 1))) (cdr (vector-ref vc j)))
+	  (format *stderr* "~A > ~A?~%" (cdr (vector-ref vc (- j 1))) (cdr (vector-ref vc j))))))
   
   (define (check-cadr vc)
-    (let ((x (vector-ref vc 0)))
-      (for-each
-       (lambda (y)
-	 (if (> (cadr x) (cadr y)) 
-	     (format *stderr* "~A > ~A?~%" (cadr x) (cadr y)))
-	 (set! x y))
-       (subvector vc 1 size))))
+    (do ((j 1 (+ j 1)))
+	((= j size))
+      (if (> (cadr (vector-ref vc (- j 1))) (cadr (vector-ref vc j)))
+	  (format *stderr* "~A > ~A?~%" (cadr (vector-ref vc (- j 1))) (cadr (vector-ref vc j))))))
 	 
   (define (vfill-n v x)
     (do ((i 0 (+ i 1)))
